==> foxpost-0.1.7.zip: foxpost/controllers/admin/AdminFoxPostController.php <==
<?php
require_once _PS_ROOT_DIR_ . '/modules/foxpost/classes/FPPackage.php';

use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * FoxPost official plugin
 *
 * @author Foxpost <kovago.balazs@foxpost.hu>
 * @copyright 2022 FoxPost Zrt.
 * @license   See joined file licence.txt
 * @category  Module
 * @support   Support <b2chelpdesk@foxpost.hu>
 * @version   0.0.1
 * @link      https://www.foxpost.hu
 */

if (!defined('_PS_VERSION_')) exit;


class AdminFoxPostController extends ModuleAdminController
{

    private $API_LOG_LEVEL = 2;
    /** @var string $translate_function Determines the function used for translate strings, based on version */
    private $translate_function = "l";
    /** @var string $ajax_response_function Determines the function used for ajax response, based on version */
    private $ajax_response_function = "ajaxDie";
    public function __construct()
    {
        parent::__construct();
        // Base
        $this->bootstrap = false; // use Bootstrap CSS
        $this->table = ''; // SQL table name, will be prefixed with _DB_PREFIX_
        $this->identifier = ''; // SQL column to be used as primary key
        $this->className = ''; // PHP class name
        $this->allow_export = false; // allow export in CSV, XLS..
        $this->visible = false;
        $this->module = 'foxpost';

        $this->API_LOG_LEVEL = Configuration::get('FOXPOST_API_LOG_LEVEL');
        if (_PS_MODE_DEV_ == true) $this->API_LOG_LEVEL = 6;
        $this->translate_function = version_compare(_PS_VERSION_, '8.0.0', '<') ? "l" : "trans";
        $this->ajax_response_function = version_compare(_PS_VERSION_, '8.0.0', '<') ? "ajaxDie" : "ajaxRender";
    }


    /**
     * Print label
     *
     * @throws PrestaShopDatabaseException
     * @throws PrestaShopException
     */
    //public function ProcessPrintLabel() 
    public function ajaxProcessPrintLabel()
    {
        //$this->ajax     = true;
        $id_order = (int)Tools::getValue('id_order');
        $order = new Order($id_order);

        if (!Validate::isLoadedObject($order)) {
            exit('Order not exists');
        }

        $FoxPostApi = $this->getAPI($this->API_LOG_LEVEL); //print_r($FoxPostApi);
        $FoxPostApi->setTmpDir(dirname(__FILE__) . DIRECTORY_SEPARATOR . '../../logs' . DIRECTORY_SEPARATOR . 'API' . DIRECTORY_SEPARATOR);

        $package = FPPackage::getShipmentInfoByOrderId($id_order);

        if ($package['printed'] == 1 && FoxPost::getConfig('RELABEL', 0) == 0) {
            //$this->ajaxDie(json_encode(array('success'=> false, 'message' => $this->trans('This label is printed before! If you wish enable: "Generate lot of PDF label"!'), 'trackingnumber' => $package['barcode'])));              

            $this->container->get('session')->getFlashBag()->add('error', Context::getContext()->getTranslator()->trans('This label is printed before! If you wish enable: "Generate lot of PDF label"!'));

            Tools::redirectAdmin(
                Context::getContext()->link->getAdminLink(
                    'AdminOrders',
                    true,
                    [],
                    ['vieworder' => true, 'id_order' => (int) $id_order]
                )
            );
        }

        $pdf_name = $FoxPostApi->parcelLabel(array($package['barcode']), FoxPost::getConfig('LABEL_SIZE', 'A7')); //  var_dump($package);   var_dump($FoxPostApi);        

        if ($FoxPostApi->error == true) {
            //If error redirect
            //exit("API error: ".$FoxPostApi->getLog() );
            $this->container->get('session')->getFlashBag()->add('error', Context::getContext()->getTranslator()->trans('API error! See log file to detailed information.'));

            Tools::redirectAdmin(
                Context::getContext()->link->getAdminLink(
                    'AdminOrders',
                    true,
                    [],
                    ['vieworder' => true, 'id_order' => (int) $id_order]
                )
            );
        }

        $file = _PS_MODULE_DIR_ . "foxpost/logs/API/labels/{$pdf_name}";
        $filesize = filesize($file);
        if ($filesize > 1) {
            FPPackage::setS2($package['barcode']);

            header('Expires: 0');
            header('Cache-Control: must-revalidate');
            header('Pragma: public');
            header("Content-Type: application/pdf");
            //header("Content-Disposition: inline; filename={$pdf_name}");
            header('Content-Length: ' . $filesize);
            header('Content-Description: File Transfer');
            header("Content-Disposition: attachment;  filename={$pdf_name}");

            readfile($file);
            exit;
        }

        //If error redirect
        //exit("API/PDF error: ".$FoxPostApi->getLog() );
        $this->container->get('session')->getFlashBag()->add('error', Context::getContext()->getTranslator()->trans('API error! See log file to detailed information.'));

        Tools::redirectAdmin(
            Context::getContext()->link->getAdminLink(
                'AdminOrders',
                true,
                [],
                ['vieworder' => true, 'id_order' => (int) $id_order]
            )
        );
    }



    /**
     * Order shippment by ajax
     *
     * @return mixed|string
     * @throws PrestaShopDatabaseException
     * @throws PrestaShopException
     */
    public function ajaxProcessCreateLabel()
    {
        $this->ajax     = true;
        $id_order       = (int)Tools::getValue('id_order');
        $parcel_size    = Tools::getValue('parcel_size');
        $order          = new Order($id_order);



        $package = FPPackage::getFPPackageByOrderId($id_order);
        if (!empty($parcel_size)) {
            $package->parcel_size = pSQL($parcel_size);
            $package->update();
        }

        if ($package->status > 0 /*$package->barcode!=''*/ && FoxPost::getConfig('REPARCEL', 0) == 0) {
            $this->{$this->ajax_response_function}(json_encode(array('success' => false, 'message' => Context::getContext()->getTranslator()->trans('Only once send parcel to Foxpost! \'Export CSV and send to Foxpost API\' not enabled!'), 'trackingnumber' => $package->barcode)));
        }


        //FoxPost
        $messages = [];
        $label = FPHelper::getLabelFromFoxPost(array($order), $messages, 6);

        if ($label == false) {
            $this->{$this->ajax_response_function}(json_encode(array('success' => false, 'message' => FPHelper::getStringFromArray($messages), 'trackingnumber' => '')));
        }
        //print_r($package);echo $messages;exit;
        $tracking_number = $label[$id_order];


        //PrestaShop        
        $ps = FPHelper::setLabelToPrestaShop($order, $tracking_number);
        if ($ps == false)
            $this->{$this->ajax_response_function}(json_encode(array('success' => false, 'message' => Context::getContext()->getTranslator()->trans('The order carrier cannot be updated.'),  'trackingnumber' => '')));
        else
            $this->{$this->ajax_response_function}(json_encode(array('success' => true,  'message' => Context::getContext()->getTranslator()->trans('Label created.'),                        'trackingnumber' => $tracking_number)));
    }


    /**
     * 
     */
    public function ajaxProcessDlLog()
    {
        $this->ajax = true;

        $filename = (int)Tools::getValue('file');

        $file = _PS_MODULE_DIR_ . "foxpost/logs/API/logs/{$filename}.log";

        if (file_exists($file)) {
            $filesize = filesize($file);
            header('Expires: 0');
            header('Cache-Control: must-revalidate');
            header('Pragma: public');
            header("Content-Type: text/plain");
            header("Content-Disposition: attachment; filename={$filename}.log");
            header('Content-Length: ' . $filesize);
            header('Content-Description: File Transfer');

            readfile($file);
            exit;
        }
        exit('File not exist!');
    }


    /**
     * Configure FoxPostApi to this enviromment 
     * 
     * @param $loglevel API log level
     * @return object API object
     */
    private function getAPI(int $loglevel = 2)
    {

        //if ( is_null($this->FoxPostApi) || ( ! $this->FoxPostApi instanceof FoxPostApi ) ){
        $FoxPostApi = new FoxPostApi($this->API_LOG_LEVEL);
        $logdir = dirname(__FILE__) . DIRECTORY_SEPARATOR . '../../logs' . DIRECTORY_SEPARATOR . 'API' . DIRECTORY_SEPARATOR;
        //if (!file_exists($logdir)) mkdir($logdir, true);
        $FoxPostApi->setTmpDir($logdir);
        $FoxPostApi->setCred(Configuration::get('FOXPOST_USER'), Configuration::get('FOXPOST_PASS'), Configuration::get('FOXPOST_API'));
        $FoxPostApi->setUserAgent(array('PrestaShop' => _PS_VERSION_));
        $this->FoxPostApi = $FoxPostApi;
        //} 
        //return $this->FoxPostApi; 
        return $FoxPostApi;
    }
}

==> foxpost-1.0.0.zip: foxpost/controllers/admin/AdminFoxPostController.php <==
<?php
require_once _PS_ROOT_DIR_ . '/modules/foxpost/classes/FPPackage.php';

use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * FoxPost official plugin
 *
 * @author Foxpost <kovago.balazs@foxpost.hu>
 * @copyright 2022 FoxPost Zrt.
 * @license   See joined file licence.txt
 * @category  Module
 * @support   Support <b2chelpdesk@foxpost.hu>
 * @version   0.0.1
 * @link      https://www.foxpost.hu
 */

if (!defined('_PS_VERSION_')) exit;


class AdminFoxPostController extends ModuleAdminController
{

    private $API_LOG_LEVEL = 2;
    /** @var string $translate_function Determines the function used for translate strings, based on version */
    private $translate_function = "l";
    /** @var string $ajax_response_function Determines the function used for ajax response, based on version */
    private $ajax_response_function = "ajaxDie";
    public function __construct()
    {
        parent::__construct();
        // Base
        $this->bootstrap = false; // use Bootstrap CSS
        $this->table = ''; // SQL table name, will be prefixed with _DB_PREFIX_
        $this->identifier = ''; // SQL column to be used as primary key
        $this->className = ''; // PHP class name
        $this->allow_export = false; // allow export in CSV, XLS..
        $this->visible = false;
        $this->module = 'foxpost';

        $this->API_LOG_LEVEL = Configuration::get('FOXPOST_API_LOG_LEVEL');
        if (_PS_MODE_DEV_ == true) $this->API_LOG_LEVEL = 6;
        $this->translate_function = version_compare(_PS_VERSION_, '8.0.0', '<') ? "l" : "trans";
        $this->ajax_response_function = version_compare(_PS_VERSION_, '8.0.0', '<') ? "ajaxDie" : "ajaxRender";
    }


    /**
     * Print label
     *
     * @throws PrestaShopDatabaseException
     * @throws PrestaShopException
     */
    //public function ProcessPrintLabel() 
    public function ajaxProcessPrintLabel()
    {
        //$this->ajax     = true;
        $id_order = (int)Tools::getValue('id_order');
        $order = new Order($id_order);

        if (!Validate::isLoadedObject($order)) {
            exit('Order not exists');
        }

        $FoxPostApi = $this->getAPI($this->API_LOG_LEVEL); //print_r($FoxPostApi);
        $FoxPostApi->setTmpDir(dirname(__FILE__) . DIRECTORY_SEPARATOR . '../../logs' . DIRECTORY_SEPARATOR . 'API' . DIRECTORY_SEPARATOR);

        $package = FPPackage::getShipmentInfoByOrderId($id_order);

        if ($package['printed'] == 1 && FoxPost::getConfig('RELABEL', 0) == 0) {
            //$this->ajaxDie(json_encode(array('success'=> false, 'message' => $this->trans('This label is printed before! If you wish enable: "Generate lot of PDF label"!'), 'trackingnumber' => $package['barcode'])));              

            $this->getSession()->getFlashBag()->add('error', Context::getContext()->getTranslator()->trans('This label is printed before! If you wish enable: "Generate lot of PDF label"!'));

            Tools::redirectAdmin(
                Context::getContext()->link->getAdminLink(
                    'AdminOrders',
                    true,
                    [],
                    ['vieworder' => true, 'id_order' => (int) $id_order]
                )
            );
        }

        $pdf_name = $FoxPostApi->parcelLabel(array($package['barcode']), FoxPost::getConfig('LABEL_SIZE', 'A7')); //  var_dump($package);   var_dump($FoxPostApi);        

        if ($FoxPostApi->error == true) {
            //If error redirect
            //exit("API error: ".$FoxPostApi->getLog() );
            $this->getSession()->getFlashBag()->add('error', Context::getContext()->getTranslator()->trans('API error! See log file to detailed information.'));

            Tools::redirectAdmin(
                Context::getContext()->link->getAdminLink(
                    'AdminOrders',
                    true,
                    [],
                    ['vieworder' => true, 'id_order' => (int) $id_order]
                )
            );
        }

        $file = _PS_MODULE_DIR_ . "foxpost/logs/API/labels/{$pdf_name}";
        $filesize = filesize($file);
        if ($filesize > 1) {
            FPPackage::setS2($package['barcode']);

            header('Expires: 0');
            header('Cache-Control: must-revalidate');
            header('Pragma: public');
            header("Content-Type: application/pdf");
            //header("Content-Disposition: inline; filename={$pdf_name}");
            header('Content-Length: ' . $filesize);
            header('Content-Description: File Transfer');
            header("Content-Disposition: attachment;  filename={$pdf_name}");

            readfile($file);
            exit;
        }

        //If error redirect
        //exit("API/PDF error: ".$FoxPostApi->getLog() );
        $this->getSession()->getFlashBag()->add('error', Context::getContext()->getTranslator()->trans('API error! See log file to detailed information.'));

        Tools::redirectAdmin(
            Context::getContext()->link->getAdminLink(
                'AdminOrders',
                true,
                [],
                ['vieworder' => true, 'id_order' => (int) $id_order]
            )
        );
    }



    /**
     * Order shippment by ajax
     *
     * @return mixed|string
     * @throws PrestaShopDatabaseException
     * @throws PrestaShopException
     */
    public function ajaxProcessCreateLabel()
    {
        $this->ajax     = true;
        $id_order       = (int)Tools::getValue('id_order');
        $parcel_size    = Tools::getValue('parcel_size');
        $order          = new Order($id_order);



        $package = FPPackage::getFPPackageByOrderId($id_order);
        if (!empty($parcel_size)) {
            $package->parcel_size = pSQL($parcel_size);
            $package->update();
        }

        if ($package->status > 0 /*$package->barcode!=''*/ && FoxPost::getConfig('REPARCEL', 0) == 0) {
            $this->{$this->ajax_response_function}(json_encode(array('success' => false, 'message' => Context::getContext()->getTranslator()->trans('Only once send parcel to Foxpost! \'Export CSV and send to Foxpost API\' not enabled!'), 'trackingnumber' => $package->barcode)));
        }


        //FoxPost
        $messages = [];
        $label = FPHelper::getLabelFromFoxPost(array($order), $messages, 6);

        if ($label == false) {
            $this->{$this->ajax_response_function}(json_encode(array('success' => false, 'message' => FPHelper::getStringFromArray($messages), 'trackingnumber' => '')));
        }
        //print_r($package);echo $messages;exit;
        $tracking_number = $label[$id_order];


        //PrestaShop        
        $ps = FPHelper::setLabelToPrestaShop($order, $tracking_number);
        if ($ps == false)
            $this->{$this->ajax_response_function}(json_encode(array('success' => false, 'message' => Context::getContext()->getTranslator()->trans('The order carrier cannot be updated.'),  'trackingnumber' => '')));
        else
            $this->{$this->ajax_response_function}(json_encode(array('success' => true,  'message' => Context::getContext()->getTranslator()->trans('Label created.'),                        'trackingnumber' => $tracking_number)));
    }


    /**
     * 
     */
    public function ajaxProcessDlLog()
    {
        $this->ajax = true;

        $filename = (int)Tools::getValue('file');

        $file = _PS_MODULE_DIR_ . "foxpost/logs/API/logs/{$filename}.log";

        if (file_exists($file)) {
            $filesize = filesize($file);
            header('Expires: 0');
            header('Cache-Control: must-revalidate');
            header('Pragma: public');
            header("Content-Type: text/plain");
            header("Content-Disposition: attachment; filename={$filename}.log");
            header('Content-Length: ' . $filesize);
            header('Content-Description: File Transfer');

            readfile($file);
            exit;
        }
        exit('File not exist!');
    }


    /**
     * Configure FoxPostApi to this enviromment 
     * 
     * @param $loglevel API log level
     * @return object API object
     */
    private function getAPI(int $loglevel = 2)
    {

        //if ( is_null($this->FoxPostApi) || ( ! $this->FoxPostApi instanceof FoxPostApi ) ){
        $FoxPostApi = new FoxPostApi($this->API_LOG_LEVEL);
        $logdir = dirname(__FILE__) . DIRECTORY_SEPARATOR . '../../logs' . DIRECTORY_SEPARATOR . 'API' . DIRECTORY_SEPARATOR;
        //if (!file_exists($logdir)) mkdir($logdir, true);
        $FoxPostApi->setTmpDir($logdir);
        $FoxPostApi->setCred(Configuration::get('FOXPOST_USER'), Configuration::get('FOXPOST_PASS'), Configuration::get('FOXPOST_API'));
        $FoxPostApi->setUserAgent(array('PrestaShop' => _PS_VERSION_));
        $this->FoxPostApi = $FoxPostApi;
        //} 
        //return $this->FoxPostApi; 
        return $FoxPostApi;
    }

    /**
     * Gets session from symfony container.
     *
     * @return \Symfony\Component\HttpFoundation\Session\Session
     */
    private function getSession()
    {
        $requestStack = \PrestaShop\PrestaShop\Adapter\SymfonyContainer::getInstance()->get('request_stack');

        return $requestStack->getSession();
    }
}
